/*
 * Copyright (c) 2002 Eric Tribou <etribou@bridgew.edu>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. The name of the its contributors may not be used to endorse or
 *    promote products derived from this software without specific
 *    prior written permission.
 *
 * 2. Redistributions of source code must retain the above copyright
 *    notice and the following disclaimer.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#include <stdio.h>
#include "strnstr.h"

#define	BUFSIZE	4096

int
error(msg)
	const char	*msg;
{
	fputs(msg,stderr);
	return -1;
}

int
main(argc, argv)
	int		argc;
	char	**argv;
{
	FILE	*fpin = NULL, *fpout = NULL;
	double	count = 0, instances = 0;
	char	*str = NULL;

	if (argc < 3)
		return error("Usage: <file to read> <string> [file to write]\n");

	if ((fpin = fopen(argv[1],"r")) == NULL)
		return error("Invalid input filename.\n");

	if (argc < 4 || (fpout = fopen(argv[3],"w")) == NULL)
		fpout = stdout;

	str = (char*)malloc(sizeof(char)*BUFSIZE);
	memset(str,0,(sizeof(char)*BUFSIZE));

	while (!feof(fpin) && ++count)
	{
		if (fgets(str,BUFSIZE,fpin));
		if (strnstr((const char*)str,argv[2]) != NULL && ++instances)
			fprintf(fpout,"%04g %s",count,str);
	}

	printf("\n\n%g instance(s) of %s were found.\n",instances,argv[2]);

	if (fpin != NULL)
		fclose(fpin);

	if (fpout != NULL)
		fclose(fpout);

	if (str != NULL)
		free(str);

	return 0;
}
